==> org.eclipse.sirius.common.source_2.0.0.201410241344.jar: org/eclipse/sirius/common/tools/api/resource/AbstractResourceSyncBackend.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2008 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.common.tools.api.resource;

import org.eclipse.emf.ecore.resource.ResourceSet;

/**
 * Backend used to synchronize a resourceset with external events about the
 * physical state of the data.
 * 
 * @author cbrun
 * 
 * @since 0.9.0
 */
public abstract class AbstractResourceSyncBackend {

    /**
     * The set the backend is focused on.
     */
    protected ResourceSet observedSet;

    /**
     * The client to update when a change occurs.
     */
    protected final ResourceSyncClient client;

    /**
     * Create a new {@link AbstractResourceSyncBackend} providing the client to
     * update when a change occurs.
     * 
     * @param client
     *            client to update when a change occurs.
     */
    public AbstractResourceSyncBackend(final ResourceSyncClient client) {
        this.client = client;
    }


    /**
     * initialize and prepare the backend.
     */
    public abstract void install();

    /**
     * de-initialize the backend.
     */
    public abstract void uninstall();

    /**
     * Specify which {@link ResourceSet} the backend should notify about.
     * 
     * @param target
     *            the resourceset to inspect.
     */
    public void setResourceSet(final ResourceSet target) {
        this.observedSet = target;
    }

}

==> org.eclipse.sirius.common.source_7.4.8.202503250835.jar: org/eclipse/sirius/common/tools/api/resource/AbstractResourceSyncBackend.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2008 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.common.tools.api.resource;

import org.eclipse.emf.ecore.resource.ResourceSet;

/**
 * Backend used to synchronize a resourceset with external events about the
 * physical state of the data.
 * 
 * @author cbrun
 * 
 * @since 0.9.0
 */
public abstract class AbstractResourceSyncBackend {

    /**
     * The set the backend is focused on.
     */
    protected ResourceSet observedSet;

    /**
     * The client to update when a change occurs.
     */
    protected final ResourceSyncClient client;

    /**
     * Create a new {@link AbstractResourceSyncBackend} providing the client to
     * update when a change occurs.
     * 
     * @param client
     *            client to update when a change occurs.
     */
    public AbstractResourceSyncBackend(final ResourceSyncClient client) {
        this.client = client;
    }

    /**
     * initialize and prepare the backend.
     */
    public void install() {

    }

    /**
     * de-initialize the backend.
     */
    public void uninstall() {
        observedSet = null;
    }

    /**
     * Specify which {@link ResourceSet} the backend should notify about.
     * 
     * @param target
     *            the resourceset to inspect.
     */
    public void setResourceSet(final ResourceSet target) {
        this.observedSet = target;
    }

}
